package it.unibs.fp.patenteelibbrettopregoh;

import java.util.ArrayList;

/**
 * Classe che rappresenta una lista di comuni.
 */
public class Comuni {
    private final ArrayList<Comune> comuni;

    /**
     * Costruttore della classe Comuni.
     * Inizializza la lista di comuni.
     */
    public Comuni() {
        this.comuni = new ArrayList<>();
    }

    /**
     * Aggiunge un comune alla lista.
     *
     * @param comune il comune da aggiungere
     */
    public void addComune(Comune comune) {
        this.comuni.add(comune);
    }

    /**
     * Rimuove un comune dalla lista.
     *
     * @param comune il comune da rimuovere
     */
    public void removeComune(Comune comune) {
        this.comuni.remove(comune);
    }

    /**
     * Restituisce la lista di comuni.
     *
     * @return la lista di comuni
     */
    public ArrayList<Comune> getComuni() {
        return comuni;
    }

    /**
     * Restituisce il codice del comune dato il nome.
     *
     * @param nomeComune il nome del comune
     * @return il codice del comune, oppure null se non trovato
     */
    public String getCodiceComune(String nomeComune) {
        for (Comune comune : comuni) {
            if (comune.getNome().equalsIgnoreCase(nomeComune)) {
                return comune.getCodice();
            }
        }
        return null; // Comune non trovato
    }

}
