package it.unibs.fp.patenteelibbrettopregoh;

import com.google.gson.annotations.SerializedName;

// import java.time.LocalDate;
import java.util.ArrayList;

/**
 * La classe PaginaDiario rappresenta una pagina del diario di un personaggio.
 * Ogni pagina contiene la data, il bilancio e una lista di persone controllate.
 */
public class PaginaDiario {
    private final String data; // per nevitare problemi con Gson e la serializzazione di LocalDate
    private final double bilancio;
    @SerializedName("persone")
    private final ArrayList<PersonaControllata> personeControllate;

    /**
     * Costruttore della classe PaginaDiario.
     *
     * @param data     la data della pagina
     * @param bilancio il bilancio della pagina
     */
    public PaginaDiario(String data, double bilancio) {
        this.data = data;
        this.bilancio = bilancio;
        this.personeControllate = new ArrayList<>();
    }

    /**
     * Restituisce il giorno.
     *
     * @return il giorno della data
     */
    public int getGiorno() {
        return Integer.parseInt(data.split("-")[2]);
    }

    /**
     * Restituisce la data.
     *
     * @return la data
     */
    public String getData() {
        return data;
    }

    /**
     * Restituisce il bilancio.
     *
     * @return il bilancio
     */
    public double getBilancio() {
        return bilancio;
    }

    /**
     * Restituisce la lista di persone controllate.
     *
     * @return la lista di persone controllate
     */
    public ArrayList<PersonaControllata> getPersoneControllate() {
        return personeControllate;
    }

    /**
     * aggiunge una persona controllata alla pagina del diario.
     *
     * @param persona la persona da aggiungere
     */
    public void addPersonaControllata(PersonaControllata persona) {
        this.personeControllate.add(persona);
    }

    /**
     * rimuove una persona controllata dalla pagina del diario.
     *
     * @param persona la persona da rimuovere
     */
    public void removePersonaControllata(PersonaControllata persona) {
        this.personeControllate.remove(persona);
    }

}
